@@ -31,7 +31,7 @@ BEGIN {
     Win32::API::->Import("psapi","BOOL EnumProcessModules(HANDLE  hProcess, HMODULE *lphModule, DWORD   cb, LPDWORD lpcbNeeded)") or die "EnumProcessModules: $^E";  # uncoverable branch true
 }
 
-our $VERSION = '0.009'; # auto-populated from W::M::NPP
+our $VERSION = '0.010'; # auto-populated from W::M::NPP
 
 our @EXPORT_VARS = (@Win32::Mechanize::NotepadPlusPlus::Notepad::Messages::EXPORT);
 
@@ -1199,6 +1199,59 @@ sub destroyScintilla {
 
 =for comment /end of Hidden Scintilla Instances
 
+=head2 Modes
+
+=head3 Auto-Indentation
+
+Accesses the Auto-Indentation for the active lexer.
+
+=over
+
+=item isAutoIndentOn
+
+    my $isauto = notepad->isAutoIndentOn();
+
+Gets the current state of the Use Auto-Indentation setting in the Notepad++ preferences.
+
+=cut
+
+sub isAutoIndentOn {
+    my $self = shift;
+    return $self->SendMessage( $NPPMSG{NPPM_ISAUTOINDENTON}, 0, 0);
+    # NPPM_ISAUTOINDENTON
+}
+
+=back
+
+=head3 Macro Recording
+
+Accesses the Macro Recording state
+
+=over
+
+=item getCurrentMacroStatus
+
+    my $macro_state = notepad->getCurrentMacroStatus();
+    print "macro state name = ", $MACROSTATUS{$macro_state}, "\n";
+
+Gets the current state of the Macro Recording feature of Notepad++.
+
+Returns one of the L<%MACROSTATUS|Win32::Mechanize::NotepadPlusPlus::Notepad::Messages/"%MACROSTATUS"> values.
+That has maps name to value and value to name, so you can use the return value as a key in that hash to
+get the associated name of the state.
+
+=cut
+
+sub getCurrentMacroStatus {
+    my $self = shift;
+    return $self->SendMessage( $NPPMSG{NPPM_GETCURRENTMACROSTATUS}, 0, 0);
+    # NPPM_GETCURRENTMACROSTATUS
+}
+
+=back
+
+=for comment /end of Modes
+
 =head2 GUI Manipulation
 
 =over
@@ -1429,7 +1482,7 @@ For C<$statusBarSection>, use one of the L<%STATUSBAR|Win32::Mechanize::NotepadP
 sub _populateStatusBarHwnd {
     my ($self) = @_;
     return $self->{_sbhwobj} if $self->{_sbhwobj};
-    
+
     my $sbWnd;
 
     for my $cWnd ( GetChildWindows($self->hwnd) )
@@ -1445,7 +1498,7 @@ sub getStatusBar {
     # NPPM_GETSTATUSBAR -- Does Not Exist! so I have to work around that using Win32 calls
     my ($self, $section) = @_;
     $section = $STATUSBAR{$section} if exists $STATUSBAR{$section};   # allow name or value
-    
+
     my ($SB_GETTEXTLENGTHW , $SB_GETTEXTW ) = map {0x400 + $_} 12, 13; # WM_USER + offset
 
     $self->_populateStatusBarHwnd();
@@ -1486,18 +1539,39 @@ sub isDocListShown {
     return $self->SendMessage( $NPPMSG{NPPM_ISDOCLISTSHOWN}, 0, 0);
 }
 
-=item docListDisableColumn
+=item docListDisableExtColumn
 
-    notepad->docListDisableColumn($disableOrNot);   # disables the extension column if disableOrNot is true
+    notepad->docListDisableExtColumn($disableOrNot);   # disables the extension column if disableOrNot is true
 
 Sets whether or not the Document List panel disables (1) or shows (0) the extension in a separate column.
 
+(Requires NPP v8.1.3 or newer.  Through module version 0.009, this was called C<docListDisableColumn>, but renamed to match the v8.1.5 API naming
+convention.  The old name is an alias to the new name.)
+
 =cut
 
-sub docListDisableColumn {
-    # NPPM_DOCLISTDISABLECOLUMN, wParam=0, lParam=boolean
+sub docListDisableExtColumn {
+    # NPPM_DOCLISTDISABLEEXTCOLUMN, wParam=0, lParam=boolean
     my ($self, $toDisableOrNot) = @_;
-    return $self->SendMessage( $NPPMSG{NPPM_DOCLISTDISABLECOLUMN}, 0, $toDisableOrNot);
+    return $self->SendMessage( $NPPMSG{NPPM_DOCLISTDISABLEEXTCOLUMN}, 0, $toDisableOrNot);
+}
+
+*docListDisableColumn = \&docListDisableExtColumn;
+
+=item docListDisablePathColumn
+
+    notepad->docListDisablePathColumn($disableOrNot);   # disables the path column if disableOrNot is true
+
+Sets whether or not the Document List panel disables (1) or shows (0) the path column.
+
+(Requires NPP v8.1.5 or newer.)
+
+=cut
+
+sub docListDisablePathColumn {
+    # NPPM_DOCLISTDISABLEPATHCOLUMN, wParam=0, lParam=boolean
+    my ($self, $toDisableOrNot) = @_;
+    return $self->SendMessage( $NPPMSG{NPPM_DOCLISTDISABLEPATHCOLUMN}, 0, $toDisableOrNot);
 }
 
 =item getLineNumberWidthMode
@@ -2053,6 +2127,7 @@ my %nppVarMsg = (
     $INTERNALVAR{NPP_DIRECTORY}            => $NPPMSG{NPPM_GETNPPDIRECTORY},
     $INTERNALVAR{GETFILENAMEATCURSOR}      => $NPPMSG{NPPM_GETFILENAMEATCURSOR},
     $INTERNALVAR{CURRENT_LINE}             => $NPPMSG{NPPM_GETCURRENTLINE},
+    $INTERNALVAR{CURRENT_LINESTR}          => $NPPMSG{NPPM_GETCURRENTLINESTR},
     $INTERNALVAR{CURRENT_COLUMN}           => $NPPMSG{NPPM_GETCURRENTCOLUMN},
     $INTERNALVAR{NPP_FULL_FILE_PATH}       => $NPPMSG{NPPM_GETNPPFULLFILEPATH},
 );
@@ -2115,8 +2190,8 @@ in all instances or versions of Notepad++.
     'current ansi codepage' | Codepage number active for "ANSI" files
     'plugins'               | Space-separated list of plugin DLLs loaded
 
-The first time this method is called in any script will trigger the 
-Debug Info dialog briefly, but it is automatically closed after the 
+The first time this method is called in any script will trigger the
+Debug Info dialog briefly, but it is automatically closed after the
 information is retrieved.
 
 =cut
