@@ -4,7 +4,24 @@ use warnings;
 use strict;
 use Exporter 5.57 ('import');
 
-our @EXPORT = qw/%NPPMSG %VIEW %MODELESS %STATUSBAR %MENUHANDLE %INTERNALVAR %LANGTYPE %LINENUMWIDTH %WINVER %WINPLATFORM %WINMSGBOX %NOTIFICATION %DOCSTATUS %NPPIDM %BUFFERENCODING/;
+our @EXPORT = qw/
+    %BUFFERENCODING
+    %DOCSTATUS
+    %INTERNALVAR
+    %LANGTYPE
+    %LINENUMWIDTH
+    %MACROSTATUS
+    %MENUHANDLE
+    %MODELESS
+    %NOTIFICATION
+    %NPPIDM
+    %NPPMSG
+    %STATUSBAR
+    %VIEW
+    %WINMSGBOX
+    %WINPLATFORM
+    %WINVER
+/;
 
 =encoding utf8
 
@@ -70,8 +87,10 @@ our %NPPMSG = (
     'NPPM_DMMSHOW'                                               => ((1024 + 1000) + 30),
     'NPPM_DMMUPDATEDISPINFO'                                     => ((1024 + 1000) + 32),
     'NPPM_DMMVIEWOTHERTAB'                                       => ((1024 + 1000) + 35),
-    'NPPM_DOCSWITCHERDISABLECOLUMN'                              => ((1024 + 1000) + 89),
-    'NPPM_DOCLISTDISABLECOLUMN'                                  => ((1024 + 1000) + 89), 	# v8.1.3
+    'NPPM_DOCSWITCHERDISABLECOLUMN'                              => ((1024 + 1000) + 89),   # renamed in v8.1.3
+    'NPPM_DOCLISTDISABLECOLUMN'                                  => ((1024 + 1000) + 89), 	# new name in v8.1.3
+    'NPPM_DOCLISTDISABLEEXTCOLUMN'                               => ((1024 + 1000) + 89), 	# new name in v8.1.5
+    'NPPM_DOCLISTDISABLEPATHCOLUMN'                              => ((1024 + 1000) + 102), 	# new to v8.1.5
     'NPPM_DOOPEN'                                                => ((1024 + 1000) + 77),
     'NPPM_ENCODESCI'                                             => ((1024 + 1000) + 26),
     'NPPM_GETAPPDATAPLUGINSALLOWED'                              => ((1024 + 1000) + 87),
@@ -85,6 +104,8 @@ our %NPPMSG = (
     'NPPM_GETCURRENTDOCINDEX'                                    => ((1024 + 1000) + 23),
     'NPPM_GETCURRENTLANGTYPE'                                    => ((1024 + 1000) + 5),
     'NPPM_GETCURRENTLINE'                                        => ((1024 + 3000) + 8),
+    'NPPM_GETCURRENTLINESTR'                                     => ((1024 + 3000) + 12),
+    'NPPM_GETCURRENTMACROSTATUS'                                 => ((1024 + 1000) + 106),  # v8.3.3
     'NPPM_GETCURRENTNATIVELANGENCODING'                          => ((1024 + 1000) + 79),
     'NPPM_GETCURRENTSCINTILLA'                                   => ((1024 + 1000) + 4),
     'NPPM_GETCURRENTVIEW'                                        => ((1024 + 1000) + 88),
@@ -122,6 +143,7 @@ our %NPPMSG = (
     'NPPM_HIDESTATUSBAR'                                         => ((1024 + 1000) + 74),
     'NPPM_HIDETABBAR'                                            => ((1024 + 1000) + 51),
     'NPPM_HIDETOOLBAR'                                           => ((1024 + 1000) + 70),
+    'NPPM_ISAUTOINDENTON'                                        => ((1024 + 1000) + 105),  # v8.3.3
     'NPPM_ISDOCSWITCHERSHOWN'                                    => ((1024 + 1000) + 86),
     'NPPM_ISDOCLISTSHOWN'                                        => ((1024 + 1000) + 86),	# v8.1.3
     'NPPM_ISMENUHIDDEN'                                          => ((1024 + 1000) + 73),
@@ -265,7 +287,6 @@ our %MENUHANDLE = (
 
 Pass these to L<getNppDir()|Win32::Mechanize::NotepadPlusPlus::Notepad/getNppDir> to access the internal variables described L<in the Macros section of the official docs|https://npp-user-manual.org/docs/config-files/#macros>.
 
-
     Key                 | Description                               | Example
     --------------------+-------------------------------------------+----------------------------
     FULL_CURRENT_PATH   | full path to the active file              | E:\My Web\main\welcome.html
@@ -275,6 +296,7 @@ Pass these to L<getNppDir()|Win32::Mechanize::NotepadPlusPlus::Notepad/getNppDir
     EXT_PART            | extension                                 | html
     CURRENT_WORD        | active selection or word under the cursor | text
     CURRENT_LINE        | line number of cursor location            | 1
+    CURRENT_LINESTR     | text of the current line                  | tex of whole line
     CURRENT_COLUMN      | column number of cursor location          | 5
     NPP_DIRECTORY       | notepad++ executable's directory          | c:\Program Files\notepad++
     NPP_FULL_FILE_PATH  | full path to the notepad++.exe            | c:\Program Files\notepad++\notepad++.exe
@@ -295,6 +317,7 @@ our %INTERNALVAR = (
     'CURRENT_COLUMN'                                             => 9,
     'NPP_FULL_FILE_PATH'                                         => 10,
     'GETFILENAMEATCURSOR'                                        => 11,
+    'CURRENT_LINESTR'                                            => 12,
 );
 
 =item %LANGTYPE
@@ -1160,6 +1183,8 @@ our %NPPIDM = (
     'IDM_WIKIFAQ'                                                => ((40000  + 7000)  + 7),
 );
 
+=head2 OTHER USEFUL ENUMERATIONS
+
 =over
 
 =item DEPRECATED %ENCODINGKEY
@@ -1204,8 +1229,6 @@ as the first bytes in the saved file.
     3                       | UCS2_LE_BOM   | (string)
     4                       | UTF8_NO_BOM   | (string)
 
-=back
-
 =cut
 
 our %BUFFERENCODING = (
@@ -1234,6 +1257,41 @@ our %BUFFERENCODING = (
     uniCookie       => 4,
 );
 
+=item %MACROSTATUS
+
+These are the values returned by 
+L<notepad-E<gt>getCurrentMacroStatus|Win32::Mechanize::NotepadPlusPlus::Notepad/getCurrentMacroStatus> 
+This hash provides a two way map: so its keys include both the string names (with the integers as values) 
+and the integers (with the string names as values).
+
+    Name                    | Integer       | Description
+    ------------------------+---------------+-----------------
+    Idle                    | 0             | No macro activity (normal/default state)
+    RecordInProgress        | 1             | Macro recording has started
+    RecordingStopped        | 2             | Macro recording has completed
+    PlayingBack             | 3             | Macro is being played back (rare)
+
+The C<PlayingBack> state is not common, because your script has to have called
+C<getCurrentMacroStatus> during the brief time that the macro playback is in
+progress.  (Unless you have a complicated search/replace and a large document,
+it's not likely to see this state.)
+
+=cut
+
+our %MACROSTATUS = (
+    # name => number
+    Idle                => 0,
+    RecordInProgress    => 1,
+    RecordingStopped    => 2,
+    PlayingBack         => 3,
+    # number => name
+    0                   => 'Idle',
+    1                   => 'RecordInProgress',
+    2                   => 'RecordingStopped',
+    3                   => 'PlayingBack',
+);
+
+=back
 
 =head1 INSTALLATION
 
