@@ -1,4 +1,4 @@
-# auto-converted from src/Notepad_plus_msgs.h at Sat Mar 27 12:58:57 2021
+# auto-converted from src/Notepad_plus_msgs.h at Fri Sep 10 09:49:00 2021
 package Win32::Mechanize::NotepadPlusPlus::Notepad::Messages;
 
 use warnings;
@@ -45,7 +45,7 @@ our %nppm_dummyhash = (
     'L_DIFF'                                                     => 33,
     'L_ERLANG'                                                   => 71,
     'L_ESCRIPT'                                                  => 72,
-    'L_EXTERNAL'                                                 => 85,
+    'L_EXTERNAL'                                                 => 86,
     'L_FLASH'                                                    => 27,
     'L_FORTH'                                                    => 73,
     'L_FORTRAN'                                                  => 25,
@@ -69,7 +69,7 @@ our %nppm_dummyhash = (
     'L_MAKEFILE'                                                 => 10,
     'L_MATLAB'                                                   => 44,
     'L_MMIXAL'                                                   => 75,
-    'L_NIMROD'                                                   => 76,
+    'L_NIM'                                                      => 76,
     'L_NNCRONTAB'                                                => 77,
     'L_NSIS'                                                     => 28,
     'L_OBJC'                                                     => 5,
@@ -100,6 +100,7 @@ our %nppm_dummyhash = (
     'L_TEX'                                                      => 24,
     'L_TEXT'                                                     => 0,
     'L_TXT2TAGS'                                                 => 83,
+    'L_TYPESCRIPT'                                               => 85,
     'L_USER'                                                     => 15,
     'L_VB'                                                       => 18,
     'L_VERILOG'                                                  => 43,
@@ -114,7 +115,8 @@ our %nppm_dummyhash = (
     'NPPMAINMENU'                                                => 1,
     'NPPMSG'                                                     => (1024 + 1000),
     'NPPM_ACTIVATEDOC'                                           => ((1024 + 1000) + 28),
-    'NPPM_ADDTOOLBARICON'                                        => ((1024 + 1000) + 41),
+    'NPPM_ADDTOOLBARICON_DEPRECATED'                             => ((1024 + 1000) + 41),
+    'NPPM_ADDTOOLBARICON_FORDARKMODE'                            => ((1024 + 1000) + 101),
     'NPPM_ALLOCATECMDID'                                         => ((1024 + 1000) + 81),
     'NPPM_ALLOCATEMARKER'                                        => ((1024 + 1000) + 82),
     'NPPM_ALLOCATESUPPORTED'                                     => ((1024 + 1000) + 80),
@@ -128,7 +130,7 @@ our %nppm_dummyhash = (
     'NPPM_DMMSHOW'                                               => ((1024 + 1000) + 30),
     'NPPM_DMMUPDATEDISPINFO'                                     => ((1024 + 1000) + 32),
     'NPPM_DMMVIEWOTHERTAB'                                       => ((1024 + 1000) + 35),
-    'NPPM_DOCSWITCHERDISABLECOLUMN'                              => ((1024 + 1000) + 89),
+    'NPPM_DOCLISTDISABLECOLUMN'                                  => ((1024 + 1000) + 89),
     'NPPM_DOOPEN'                                                => ((1024 + 1000) + 77),
     'NPPM_ENCODESCI'                                             => ((1024 + 1000) + 26),
     'NPPM_GETAPPDATAPLUGINSALLOWED'                              => ((1024 + 1000) + 87),
@@ -179,7 +181,7 @@ our %nppm_dummyhash = (
     'NPPM_HIDESTATUSBAR'                                         => ((1024 + 1000) + 74),
     'NPPM_HIDETABBAR'                                            => ((1024 + 1000) + 51),
     'NPPM_HIDETOOLBAR'                                           => ((1024 + 1000) + 70),
-    'NPPM_ISDOCSWITCHERSHOWN'                                    => ((1024 + 1000) + 86),
+    'NPPM_ISDOCLISTSHOWN'                                        => ((1024 + 1000) + 86),
     'NPPM_ISMENUHIDDEN'                                          => ((1024 + 1000) + 73),
     'NPPM_ISSTATUSBARHIDDEN'                                     => ((1024 + 1000) + 75),
     'NPPM_ISTABBARHIDDEN'                                        => ((1024 + 1000) + 52),
@@ -208,7 +210,7 @@ our %nppm_dummyhash = (
     'NPPM_SETMENUITEMCHECK'                                      => ((1024 + 1000) + 40),
     'NPPM_SETSMOOTHFONT'                                         => ((1024 + 1000) + 92),
     'NPPM_SETSTATUSBAR'                                          => ((1024 + 1000) + 24),
-    'NPPM_SHOWDOCSWITCHER'                                       => ((1024 + 1000) + 85),
+    'NPPM_SHOWDOCLIST'                                           => ((1024 + 1000) + 85),
     'NPPM_SWITCHTOFILE'                                          => ((1024 + 1000) + 37),
     'NPPM_TRIGGERTABBARCONTEXTMENU'                              => ((1024 + 1000) + 49),
     'NPPN_BEFORESHUTDOWN'                                        => (1000 + 19),
